function Morphology(img, binarize, r)
% apply and visualize a set of morphological operators 

% if the input image is not already BW, binarize it with otsu
if binarize
    if size(img,3)>1
        imgGL = rgb2gray(img);
    else
        imgGL = img;
    end
    level = graythresh(imgGL);
    imgBW = im2bw(img,level);
else
    imgBW = img;
end
  
% computation and visualization
m = 2;
n = 3;
figure('Name',['Erode and Dilate with SE of radius ' num2str(r)]);
subplot(m,n,1);hold on;
imshow(img);title('original');

% binarized
subplot(m,n,2);hold on;
imshow(imgBW);title('binarized');

% erode
subplot(m,n,3);hold on;
SE = strel('disk', r); 
eroded = imerode(imgBW,SE);
imshow(eroded);
title('eroded');
 
% dilate
subplot(m,n,4);hold on;
dilated=imdilate(imgBW,SE);
imshow(dilated);
title('dilated');

% open
subplot(m,n,5);hold on;
opened = imdilate(eroded,SE);
imshow(opened);title('open');

% close
subplot(m,n,6);hold on;
closed = imerode(dilated,SE);
imshow(closed);title('closed');

reps =1;
figure('Name',['Binary morphology 2/2']);
 
% outer contour
subplot(1,3,1);hold on;
imshow(logical(dilated)-logical(imgBW));title('outer contour Dilate - Original');

subplot(1,3,2);hold on;
imshow(bwmorph(imgBW,'remove', Inf));
title('outer contour with remove');

% inner contour
subplot(1,3,3);hold on;
imshow(logical(imgBW)-bwmorph(imgBW,'erode',reps));title('inner contour');

% % skeleton (Approfondimento)  
%subplot(m,n,4);hold on;
%imshow(bwmorph(imgBW,'skel',inf));title('skeleton');


end % function



