function [L] = regions(I, thresh)
%function [L] = regions(I, t) this function receives as input
%a gray scale image and a threshold (opt)
%close the holes, compute the connected regions, plot the regions with a colormap, the
%biggest one and the most eccentric. Output: the labelled connected regions

if (nargin == 1)
    thresh = graythresh(I);
end

B = im2bw(I,thresh);

%% Close the holes:
Bholes = imfill(B, 'holes');
[L, n] = bwlabel(Bholes);
 

%% Compute the attributes
attr = regionprops(L, 'eccentricity', 'area');

%% Find the maxima
[maxArea idx_Area]= max([attr.Area]);

[maxEcc, idx_Ecc] = max([attr.Eccentricity]);
  
%% Construct the binary images with only the found regions
L_max = ismember(L, idx_Area);
L_ecc = ismember(L, idx_Ecc);

%% Plot the results
subplot(2,2,1);
imshow(I); 
title('Gray scale original image');

subplot(2,2,2);
imshow(L, []);

%imshow(label2rgb(L));
%title('Connected regions');

subplot(2,2,3);
imshow(L_max);
title(['Max region Area: ' num2str(maxArea)]);

subplot(2,2,4);
imshow(L_ecc);
title(['Max eccentricity: ' num2str(maxEcc)]);

%% Display the textual information
disp(['Number of connected regions: ', num2str(n)]);
disp(['Max area: ', num2str(maxArea)]);
disp(['Max eccentricity: ', num2str(maxEcc)]);

end